package com.ruoyi.common.utils;

import java.lang.management.ManagementFactory;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.LocalTime;
import java.time.OffsetDateTime;
import java.time.YearMonth;
import java.time.ZoneId;
import java.time.ZoneOffset;
import java.time.ZonedDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Calendar;
import java.util.Date;
import java.util.List;

import org.apache.commons.lang3.time.DateFormatUtils;

/**
 * 时间工具类
 *
 * @author ruoyi
 */
public class DateUtils extends org.apache.commons.lang3.time.DateUtils
{
    public static String YYYY = "yyyy";

    public static String YYYY_MM = "yyyy-MM";

    public static String YYYY_MM_DD = "yyyy-MM-dd";

    public static String YYYYMMDDHHMMSS = "yyyyMMddHHmmss";

    public static String YYYY_MM_DD_HH_MM_SS = "yyyy-MM-dd HH:mm:ss";

    private static String[] parsePatterns = {
            "yyyy-MM-dd", "yyyy-MM-dd HH:mm:ss", "yyyy-MM-dd HH:mm", "yyyy-MM",
            "yyyy/MM/dd", "yyyy/MM/dd HH:mm:ss", "yyyy/MM/dd HH:mm", "yyyy/MM",
            "yyyy.MM.dd", "yyyy.MM.dd HH:mm:ss", "yyyy.MM.dd HH:mm", "yyyy.MM"};

    /**
     * 获取当前Date型日期
     *
     * @return Date() 当前日期
     */
    public static Date getNowDate()
    {
        return new Date();
    }

    /**
     * 获取当前日期, 默认格式为yyyy-MM-dd
     *
     * @return String
     */
    public static String getDate()
    {
        return dateTimeNow(YYYY_MM_DD);
    }

    public static final String getTime()
    {
        return dateTimeNow(YYYY_MM_DD_HH_MM_SS);
    }

    public static final String dateTimeNow()
    {
        return dateTimeNow(YYYYMMDDHHMMSS);
    }

    public static final String dateTimeNow(final String format)
    {
        return parseDateToStr(format, new Date());
    }

    public static final String dateTime(final Date date)
    {
        return parseDateToStr(YYYY_MM_DD, date);
    }

    public static final String parseDateToStr(final String format, final Date date)
    {
        return new SimpleDateFormat(format).format(date);
    }

    public static final Date dateTime(final String format, final String ts)
    {
        try
        {
            return new SimpleDateFormat(format).parse(ts);
        }
        catch (ParseException e)
        {
            throw new RuntimeException(e);
        }
    }

    /**
     * 日期路径 即年/月/日 如2018/08/08
     */
    public static final String datePath()
    {
        Date now = new Date();
        return format(now, "yyyy/MM/dd");
    }

    /**
     * 日期路径 即年/月/日 如20180808
     */
    public static final String dateTime()
    {
        Date now = new Date();
        return format(now, "yyyyMMdd");
    }

    /**
     * 日期型字符串转化为日期 格式
     */
    public static Date parseDate(Object str)
    {
        if (str == null)
        {
            return null;
        }
        try
        {
            return parseDate(str.toString(), parsePatterns);
        }
        catch (ParseException e)
        {
            return null;
        }
    }

    /**
     * 获取服务器启动时间
     */
    public static Date getServerStartDate()
    {
        long time = ManagementFactory.getRuntimeMXBean().getStartTime();
        return new Date(time);
    }

    /**
     * 计算相差天数
     */
    public static int differentDaysByMillisecond(Date date1, Date date2)
    {
        return Math.abs((int) ((date2.getTime() - date1.getTime()) / (1000 * 3600 * 24)));
    }

    /**
     * 计算时间差
     *
     * @param endDate 最后时间
     * @param startTime 开始时间
     * @return 时间差（天/小时/分钟）
     */
    public static String timeDistance(Date endDate, Date startTime)
    {
        long nd = 1000 * 24 * 60 * 60;
        long nh = 1000 * 60 * 60;
        long nm = 1000 * 60;
        // long ns = 1000;
        // 获得两个时间的毫秒时间差异
        long diff = endDate.getTime() - startTime.getTime();
        // 计算差多少天
        long day = diff / nd;
        // 计算差多少小时
        long hour = diff % nd / nh;
        // 计算差多少分钟
        long min = diff % nd % nh / nm;
        // 计算差多少秒//输出结果
        // long sec = diff % nd % nh % nm / ns;
        return day + "天" + hour + "小时" + min + "分钟";
    }

    /**
     * 增加 LocalDateTime ==> Date
     */
    public static Date toDate(LocalDateTime temporalAccessor)
    {
        ZonedDateTime zdt = temporalAccessor.atZone(ZoneId.systemDefault());
        return Date.from(zdt.toInstant());
    }

    /**
     * 增加 LocalDate ==> Date
     */
    public static Date toDate(LocalDate temporalAccessor)
    {
        LocalDateTime localDateTime = LocalDateTime.of(temporalAccessor, LocalTime.of(0, 0, 0));
        ZonedDateTime zdt = localDateTime.atZone(ZoneId.systemDefault());
        return Date.from(zdt.toInstant());
    }

    // 时间加num天
    public static Date plusDate(Date date, int num) {
        return plus(date, num, Calendar.DATE);
    }

    // 时间加num月
    public static Date plusMonth(Date date, int num) {
        return plus(date, num, Calendar.MONTH);
    }

    // 时间加num年
    public static Date plusYear(Date date, int num) {
        return plus(date, num, Calendar.YEAR);
    }

    // 添加时间
    public static Date plus(Date date, int num, int unit) {
        Calendar calendar = Calendar.getInstance();
        calendar.setTime(date);
        calendar.add(unit, num);
        return calendar.getTime();
    }


    /**
     * 日期路径 即年/月/日 如20180808
     */
    public static final String getYYYY_MM_DD(Date date)
    {
        return format(date, YYYY_MM_DD);
    }

    public static String getYYYY_MM_DD(LocalDate localDate) {
        return format(localDate, YYYY_MM_DD);
    }

    private static String format(Date date, String format) {
        return DateFormatUtils.format(date, format);
    }

    private static String format(LocalDate localDate, String format) {
        if (localDate == null) {
            return null;
        }
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern(format);
        return localDate.format(formatter);
    }
    public static Integer getYear(Date date) {
        Calendar c = Calendar.getInstance();
        c.setTime(date);
        return c.get(Calendar.YEAR);
    }

    public static Integer getMonth(Date date) {
        return date.getMonth() + 1;
    }

    public static Integer getDay(Date date) {
        LocalDate localDate = date.toInstant().atZone(ZoneId.systemDefault()).toLocalDate();
        return localDate.getDayOfMonth();
    }

    public static String getYYYY_MM(Date date) {
        return format(date, YYYY_MM);
    }

    /**
     * 获取指定月的最后一天
     * @param year 年
     * @param month 月
     */
    public static Date getMonthLastDate(Integer year, Integer month) {
        // 创建一个Calendar实例并设置为指定的日期
        Calendar calendar = Calendar.getInstance();
        calendar.set(year, month - 1, 1); // 设置为该月的第一天

        // 获取该月的最后一天
        calendar.add(Calendar.MONTH, 1); // 移动到下个月的第一天
        calendar.add(Calendar.DATE, -1); // 回退一天，回到上个月的最后一天

        // 获取最后一天的日期
        return calendar.getTime();
    }

    /**
     * 获取指定月份的第一天
     * @param year 年
     * @param month 月
     */
    public static Date getMonthFirstDate(int year, int month) {
        Date firstDay = new Date();
        firstDay.setYear(year - 1900);
        firstDay.setMonth(month - 1);
        firstDay.setDate(1);
        return firstDay;
    }

    /**
     * ISO 字符串转换为LocalDateTime
     * @param time 时间字符串:yyyy-MM-dd HH:mm:ss
     */
    public static LocalDateTime toLocalDateTimeByISO(String time) {
        DateTimeFormatter formatter = DateTimeFormatter.ISO_ZONED_DATE_TIME;
        return LocalDateTime.parse(time, formatter);
    }

    /**
     * RFC3339格式转为Date
     */
    public static Date toDateByRfc3339(String str) {
        DateTimeFormatter formatter = DateTimeFormatter.ISO_OFFSET_DATE_TIME;
        OffsetDateTime dateTime = OffsetDateTime.parse(str, formatter);
        return Date.from(dateTime.toInstant());
    }

    public static LocalDate toLocalDate(Date date) {
        return date.toInstant().atZone(ZoneId.systemDefault()).toLocalDate();
    }

    /**
     * 字符串转LocalDateTime
     * @param timeStr 字符串
     * @param format 格式化
     */
    public static LocalDateTime toLocalDate(String timeStr, String format) {
        return LocalDateTime.parse(timeStr, DateTimeFormatter.ofPattern(format));
    }

    public static LocalDateTime toLocalDateTime(Date date) {
        if (date == null) {
            return null;
        }
        return date.toInstant().atZone(ZoneId.systemDefault()).toLocalDateTime();
    }

    public static String format(LocalDateTime time, String format) {
        return time.format(DateTimeFormatter.ofPattern(format));
    }

    public static LocalDate parseLocalDate(String val) {
        return null;
    }

    /**
     * 获取列表中的最大年月，并返回最大年月的最后一天
     * @param yearMonthList 列表
     */
    public static LocalDate getMaxYearMonthLastDate(List<String> yearMonthList, String pattern) {
        if (yearMonthList == null || yearMonthList.isEmpty()) {
            return null;
        }
        YearMonth maxYearMonth = null;
        for (String yearMonth : yearMonthList) {
            YearMonth localDate = YearMonth.parse(yearMonth, DateTimeFormatter.ofPattern(pattern));
            if (maxYearMonth == null || localDate.isAfter(maxYearMonth)) {
                maxYearMonth = localDate;
            }
        }
        return maxYearMonth.atEndOfMonth();
    }

    /**
     * 获取列表中的最小年月，并返回最小年月的第一天
     * @param yearMonthList 列表
     */
    public static LocalDate getMinYearMonthFirstDate(List<String> yearMonthList, String pattern) {
        if (yearMonthList == null || yearMonthList.isEmpty()) {
            return null;
        }
        YearMonth minYearMonth = null;
        for (String yearMonth : yearMonthList) {
            YearMonth localDate = YearMonth.parse(yearMonth, DateTimeFormatter.ofPattern(pattern));
            if (minYearMonth == null || localDate.isBefore(minYearMonth)) {
                minYearMonth = localDate;
            }
        }
        return minYearMonth.atDay(1);
    }


    public static LocalDateTime toLocalDateTime(String time, String pattern) {
        if (StringUtils.isBlank(time) || StringUtils.isBlank(pattern)) {
            return null;
        }
        return LocalDateTime.parse(time, DateTimeFormatter.ofPattern(pattern));
    }

    /**
     * 将时间戳转换为LocalDateTime
     * @param timestamp 时间戳
     */
    public static LocalDateTime toLocalDateTime(Long timestamp) {
        return LocalDateTime.ofEpochSecond(timestamp, 0, ZoneOffset.of("+8"));
    }
}
