package com.ruoyi.bst.areaSub.service;

import java.util.List;

import com.ruoyi.bst.areaSub.domain.AreaSub;
import com.ruoyi.bst.areaSub.domain.AreaSubQuery;
import com.ruoyi.bst.areaSub.domain.AreaSubVO;

/**
 * 子区域Service接口
 *
 * @author ruoyi
 * @date 2025-03-15
 */
public interface AreaSubService
{
    /**
     * 查询子区域
     *
     * @param id 子区域主键
     * @return 子区域
     */
    public AreaSubVO selectAreaSubById(Long id, boolean scope);

    default AreaSubVO selectAreaSubById(Long id) {
        return this.selectAreaSubById(id, false);
    }

    /**
     * 查询子区域列表
     *
     * @param areaSub 子区域
     * @return 子区域集合
     */
    public List<AreaSubVO> selectAreaSubList(AreaSubQuery areaSub);

    /**
     * 新增子区域
     *
     * @param areaSub 子区域
     * @return 结果
     */
    public int insertAreaSub(AreaSub areaSub);

    /**
     * 修改子区域
     *
     * @param areaSub 子区域
     * @return 结果
     */
    public int updateAreaSub(AreaSub areaSub);

    /**
     * 批量删除子区域
     *
     * @param ids 需要删除的子区域主键集合
     * @return 结果
     */
    public int deleteAreaSubByIds(Long[] ids);

    /**
     * 删除子区域信息
     *
     * @param id 子区域主键
     * @return 结果
     */
    public int deleteAreaSubById(Long id);

    /**
     * 根据运营区ID查询子区域列表
     *
     * @param areaId 运营区ID
     * @return 子区域列表
     */
    public List<AreaSubVO> selectAreaSubListByAreaId(Long areaId);

    /**
     * 逻辑删除子区域
     * @param ids 子区域ID列表
     * @return 结果
     */
    public int logicDel(List<Long> ids);

    /**
     * 查询单个子区域
     * @param query 查询条件
     * @return 子区域
     */
    public AreaSubVO selectOne(AreaSubQuery query);
}
