package com.ruoyi.bst.device.service;

import java.util.List;

import com.ruoyi.bst.device.domain.Device;
import com.ruoyi.bst.device.domain.DeviceQuery;
import com.ruoyi.bst.device.domain.DeviceVO;

/**
 * 设备Service接口
 *
 * @author ruoyi
 * @date 2025-03-20
 */
public interface DeviceService
{
    /**
     * 查询设备
     *
     * @param id 设备主键
     * @return 设备
     */
    public DeviceVO selectDeviceById(Long id, boolean scope);

    default DeviceVO selectDeviceById(Long id) {
        return this.selectDeviceById(id, false);
    }

    /**
     * 查询设备列表
     *
     * @param device 设备
     * @return 设备集合
     */
    public List<DeviceVO> selectDeviceList(DeviceQuery device);

    /**
     * 新增设备
     *
     * @param device 设备
     * @return 结果
     */
    public int insertDevice(Device device);

    /**
     * 修改设备
     *
     * @param device 设备
     * @return 结果
     */
    public int updateDevice(Device device);

    /**
     * 批量删除设备
     *
     * @param ids 需要删除的设备主键集合
     * @return 结果
     */
    public int deleteDeviceByIds(Long[] ids);

    /**
     * 删除设备信息
     *
     * @param id 设备主键
     * @return 结果
     */
    public int deleteDeviceById(Long id);

    /**
     * 逻辑删除设备
     *
     * @param ids 需要删除的设备主键集合
     * @return 结果
     */
    public int logicDel(List<Long> ids);


    /**
     * 查询设备列表
     * @param ids
     * @param scope
     * @return
     */
    public List<DeviceVO> selectDeviceByIds(List<Long> ids, boolean scope);

    default List<DeviceVO> selectDeviceByIds(List<Long> ids) {
        return this.selectDeviceByIds(ids, false);
    }

    /**
     * 入仓
     */
    public int in(List<DeviceVO> deviceList);
    
    /**
     * 出仓
     */
    public int out(List<DeviceVO> deviceList);

    /**
     * 禁用
     */
    public int disable(List<DeviceVO> deviceList);

    /**
     * 启用
     */
    public int enable(List<DeviceVO> deviceList);

    /**
     * 根据sn查询设备
     * @param sn 设备sn
     * @param scope 是否数据隔离
     * @return 设备
     */
    public DeviceVO selectDeviceBySn(String sn, boolean scope);

    default DeviceVO selectDeviceBySn(String sn) {
        return this.selectDeviceBySn(sn, false);
    }

    /**
     * 根据mac查询简单的设备信息，仅包含了定位日志所需的数据
     * @param mac 设备mac
     * @return
     */
    public DeviceVO selectSimpleByMacForLocationLog(String mac);

    /**
     * 查询一个
     */
    public DeviceVO selectOne(DeviceQuery query);

    /**
     * 更新设备当前订单ID
     * @param id 设备ID
     * @param orderId 订单ID
     * @return 结果
     */
    public int updateCurrentOrderId(Long id, Long orderId);
}
