package com.ruoyi.bst.fault.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.fault.mapper.FaultMapper;
import com.ruoyi.bst.fault.domain.Fault;
import com.ruoyi.bst.fault.domain.FaultVO;
import com.ruoyi.bst.fault.domain.FaultQuery;
import com.ruoyi.bst.fault.service.FaultService;

/**
 * 故障Service业务层处理
 *
 * @author ruoyi
 * @date 2025-03-26
 */
@Service
public class FaultServiceImpl implements FaultService
{
    @Autowired
    private FaultMapper faultMapper;

    /**
     * 查询故障
     *
     * @param id 故障主键
     * @return 故障
     */
    @Override
    public FaultVO selectFaultById(Long id)
    {
        return faultMapper.selectFaultById(id);
    }

    /**
     * 查询故障列表
     *
     * @param fault 故障
     * @return 故障
     */
    @Override
    public List<FaultVO> selectFaultList(FaultQuery fault)
    {
        return faultMapper.selectFaultList(fault);
    }

    /**
     * 新增故障
     *
     * @param fault 故障
     * @return 结果
     */
    @Override
    public int insertFault(Fault fault)
    {
            fault.setCreateTime(DateUtils.getNowDate());
            return faultMapper.insertFault(fault);
    }

    /**
     * 修改故障
     *
     * @param fault 故障
     * @return 结果
     */
    @Override
    public int updateFault(Fault fault)
    {
        return faultMapper.updateFault(fault);
    }

    /**
     * 批量删除故障
     *
     * @param ids 需要删除的故障主键
     * @return 结果
     */
    @Override
    public int deleteFaultByIds(Long[] ids)
    {
        return faultMapper.deleteFaultByIds(ids);
    }

    /**
     * 删除故障信息
     *
     * @param id 故障主键
     * @return 结果
     */
    @Override
    public int deleteFaultById(Long id)
    {
        return faultMapper.deleteFaultById(id);
    }
}
