package com.ruoyi.bst.model.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.github.pagehelper.PageHelper;
import com.ruoyi.bst.model.domain.Model;
import com.ruoyi.bst.model.domain.ModelQuery;
import com.ruoyi.bst.model.domain.ModelVO;
import com.ruoyi.bst.model.mapper.ModelMapper;
import com.ruoyi.bst.model.service.ModelService;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;

/**
 * 车辆型号Service业务层处理
 *
 * @author ruoyi
 * @date 2025-03-18
 */
@Service
public class ModelServiceImpl implements ModelService
{

    @Autowired
    private ModelMapper modelMapper;
    /**
     * 查询车辆型号
     *
     * @param id 车辆型号主键
     * @return 车辆型号
     */
    @Override
    public ModelVO selectModelById(Long id, boolean scope)
    {
        ModelQuery query = new ModelQuery();
        query.setId(id);
        query.setScope(scope);
        return this.selectOne(query);
    }

    private ModelVO selectOne(ModelQuery query) {
        PageHelper.startPage(1, 1);
        List<ModelVO> list = this.selectModelList(query);
        return CollectionUtils.firstElement(list);
    }

    /**
     * 查询车辆型号列表
     *
     * @param model 车辆型号
     * @return 车辆型号
     */
    @Override
    public List<ModelVO> selectModelList(ModelQuery model)
    {
        return modelMapper.selectModelList(model);
    }

    /**
     * 新增车辆型号
     *
     * @param model 车辆型号
     * @return 结果
     */
    @Override
    public int insertModel(Model data)
    {
        data.setCreateTime(DateUtils.getNowDate());

        return modelMapper.insertModel(data);
    }

    /**
     * 修改车辆型号
     *
     * @param model 车辆型号
     * @return 结果
     */
    @Override
    public int updateModel(Model data)
    {
        return modelMapper.updateModel(data);
    }
    
    /**
     * 批量删除车辆型号
     *
     * @param ids 需要删除的车辆型号主键
     * @return 结果
     */
    @Override
    public int deleteModelByIds(Long[] ids)
    {
        return modelMapper.deleteModelByIds(ids);
    }

    /**
     * 删除车辆型号信息
     *
     * @param id 车辆型号主键
     * @return 结果
     */
    @Override
    public int deleteModelById(Long id)
    {
        return modelMapper.deleteModelById(id);
    }

    @Override
    public int logicDel(List<Long> ids) {
        if (CollectionUtils.isEmptyElement(ids)) {
            return 0;
        }
        return modelMapper.logicDel(ids);
    }
}
