package com.ruoyi.bst.order.domain;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.util.List;

import org.springframework.format.annotation.DateTimeFormat;

import com.ruoyi.bst.suit.domain.vo.SuitIntervalFeeRule;
import com.ruoyi.bst.suit.domain.vo.SuitStartFeeRule;
import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.core.domain.BaseEntity;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

/**
 * 订单对象 bst_order
 *
 * @author ruoyi
 * @date 2025-03-24
 */
@Data
public class Order extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    private Long id;

    @Excel(name = "订单号")
    @ApiModelProperty("订单号")
    private String no;

    @Excel(name = "运营区ID")
    @ApiModelProperty("运营区ID")
    private Long areaId;

    @Excel(name = "用户ID")
    @ApiModelProperty("用户ID")
    private Long userId;

    @Excel(name = "设备ID")
    @ApiModelProperty("设备ID")
    private Long deviceId;

    @Excel(name = "设备MAC")
    @ApiModelProperty("设备MAC")
    private String deviceMac;

    @Excel(name = "设备SN")
    @ApiModelProperty("设备SN")
    private String deviceSn;

    @Excel(name = "设备车牌号")
    @ApiModelProperty("设备车牌号")
    private String deviceVehicleNum;

    @Excel(name = "支付成功的支付单ID")
    @ApiModelProperty("支付成功的支付单ID")
    private Long payId;

    @Excel(name = "支付金额")
    @ApiModelProperty("支付金额")
    private BigDecimal payAmount;

    @Excel(name = "订单总金额")
    @ApiModelProperty("订单总金额")
    private BigDecimal totalFee;

    @Excel(name = "押金")
    @ApiModelProperty("押金")
    private BigDecimal depositFee;

    @Excel(name = "调度费")
    @ApiModelProperty("调度费")
    private BigDecimal dispatchFee;

    @Excel(name = "管理费")
    @ApiModelProperty("管理费")
    private BigDecimal manageFee;

    @Excel(name = "骑行费")
    @ApiModelProperty("骑行费")
    private BigDecimal ridingFee;

    @Excel(name = "车损费")
    @ApiModelProperty("车损费")
    private BigDecimal deductionFee;

    @Excel(name = "备注")
    @ApiModelProperty("备注")
    private String mark;

    @Excel(name = "订单时长", readConverterExp = "秒=")
    @ApiModelProperty("订单时长")
    private Integer duration;

    @Excel(name = "距离", readConverterExp = "米=")
    @ApiModelProperty("距离")
    private Integer distance;

    @Excel(name = "状态", readConverterExp = "W=AIT_PAY待支付,P=ROCESSING进行中,F=INISHED已结束,C=ANCEL已取消")
    @ApiModelProperty("状态")
    private String status;

    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "开始时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty("开始时间")
    private LocalDateTime startTime;

    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "结束时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty("结束时间")
    private LocalDateTime endTime;

    @Excel(name = "还车类型", readConverterExp = "1=正常还车,2=辅助还车")
    @ApiModelProperty("还车类型")
    private String returnType;

    @Excel(name = "还车视频")
    @ApiModelProperty("还车视频")
    private String videoUrl;

    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    @Excel(name = "视频上传时间", width = 30, dateFormat = "yyyy-MM-dd HH:mm:ss")
    @ApiModelProperty("视频上传时间")
    private LocalDateTime videoTime;

    @Excel(name = "通话录音")
    @ApiModelProperty("通话录音")
    private String audioFiles;

    @Excel(name = "套餐ID")
    @ApiModelProperty("套餐ID")
    private Long suitId;

    @Excel(name = "套餐类型")
    @ApiModelProperty("套餐类型")
    private String suitType;

    @Excel(name = "套餐名称")
    @ApiModelProperty("套餐名称")
    private String suitName;

    @Excel(name = "套餐免费骑行时长(分钟)")
    @ApiModelProperty("套餐免费骑行时长(分钟)")
    private Integer suitFreeRideTime;

    @Excel(name = "套餐租赁单位")
    @ApiModelProperty("套餐租赁单位")
    private String suitRentalUnit;

    @Excel(name = "套餐计费规则 ")
    @ApiModelProperty("套餐计费规则 ")
    private String suitRidingRule;

    @Excel(name = "套餐起步价计费规则json")
    @ApiModelProperty("套餐起步价计费规则json")
    private SuitStartFeeRule suitStartRule;

    @Excel(name = "套餐区间计费规则json")
    @ApiModelProperty("套餐区间计费规则json")
    private List<SuitIntervalFeeRule> suitIntervalRule;

    @Excel(name = "还车定位方式", readConverterExp = "1=设备定位,2=手机定位")
    @ApiModelProperty("还车定位方式")
    private String returnMode;

    @Excel(name = "还车经度")
    @ApiModelProperty("还车经度")
    private String returnLon;

    @Excel(name = "还车纬度")
    @ApiModelProperty("还车纬度")
    private String returnLat;

    @Excel(name = "取消备注")
    @ApiModelProperty("取消备注")
    private String cancelRemark;

    @Excel(name = "支付超时时间")
    @ApiModelProperty("支付超时时间")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private LocalDateTime payExpireTime;

}
