package com.ruoyi.bst.order.service;

import java.util.List;

import com.ruoyi.bst.order.domain.Order;
import com.ruoyi.bst.order.domain.OrderQuery;
import com.ruoyi.bst.order.domain.OrderVO;
import com.ruoyi.bst.order.domain.dto.OrderCreateDTO;
import com.ruoyi.bst.pay.domain.vo.DoPayVO;

/**
 * 订单Service接口
 *
 * @author ruoyi
 * @date 2025-03-24
 */
public interface OrderService
{
    /**
     * 查询订单
     *
     * @param id 订单主键
     * @return 订单
     */
    public OrderVO selectOrderById(Long id, boolean scope);
    
    default OrderVO selectOrderById(Long id) {
        return this.selectOrderById(id, false);
    }

    /**
     * 查询订单列表
     *
     * @param order 订单
     * @return 订单集合
     */
    public List<OrderVO> selectOrderList(OrderQuery order);

    /**
     * 新增订单
     *
     * @param order 订单
     * @return 结果
     */
    public int insertOrder(Order order);

    /**
     * 修改订单
     *
     * @param order 订单
     * @return 结果
     */
    public int updateOrder(Order order);

    /**
     * 批量删除订单
     *
     * @param ids 需要删除的订单主键集合
     * @return 结果
     */
    public int deleteOrderByIds(Long[] ids);

    /**
     * 删除订单信息
     *
     * @param id 订单主键
     * @return 结果
     */
    public int deleteOrderById(Long id);

    /**
     * 查询单个订单
     * @param query 查询条件
     * @return 订单
     */
    public OrderVO selectOne(OrderQuery query);

    /**
     * 创建订单
     * @param dto 创建订单DTO
     * @return 订单
     */
    public OrderVO createOrder(OrderCreateDTO dto);

    /**
     * 查询订单
     * @param no 订单编号
     * @param scope 是否数据隔离
     * @return 订单
     */
    public OrderVO selectOrderByNo(String no, boolean scope);

    /**
     * 查询订单
     * @param no 订单编号
     * @return 订单
     */
    default OrderVO selectOrderByNo(String no) {
        return this.selectOrderByNo(no, false);
    }

    /**
     * 取消订单
     * @param id 订单ID
     * @return 结果
     */
    public int cancelOrder(Long id);

    /**
     * 支付订单
     * @param order 订单
     * @param appId 应用ID
     * @param channelId 渠道ID
     * @return 结果
     */
    public DoPayVO pay(OrderVO order, Long appId, Long channelId);
}
