package com.ruoyi.bst.order.service.impl;

import java.time.LocalDateTime;
import java.util.Objects;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.ruoyi.bst.app.domain.AppVO;
import com.ruoyi.bst.app.service.AppService;
import com.ruoyi.bst.areaJoin.domain.AreaJoinVO;
import com.ruoyi.bst.areaJoin.service.AreaJoinService;
import com.ruoyi.bst.channel.domain.ChannelVO;
import com.ruoyi.bst.channel.service.ChannelService;
import com.ruoyi.bst.device.domain.DeviceVO;
import com.ruoyi.bst.device.service.DeviceService;
import com.ruoyi.bst.order.domain.Order;
import com.ruoyi.bst.order.domain.OrderVO;
import com.ruoyi.bst.order.domain.bo.OrderCreateBO;
import com.ruoyi.bst.order.domain.bo.OrderPayBO;
import com.ruoyi.bst.order.domain.dto.OrderCalcPrePriceDTO;
import com.ruoyi.bst.order.domain.dto.OrderCreateDTO;
import com.ruoyi.bst.order.domain.enums.OrderStatus;
import com.ruoyi.bst.order.domain.vo.OrderPrePriceVO;
import com.ruoyi.bst.order.service.OrderConverter;
import com.ruoyi.bst.order.utils.OrderUtil;
import com.ruoyi.bst.suit.domain.SuitVO;
import com.ruoyi.bst.suit.domain.enums.SuitType;
import com.ruoyi.bst.suit.service.SuitService;
import com.ruoyi.common.core.domain.vo.UserVO;
import com.ruoyi.system.user.service.UserService;

@Service
public class OrderConverterImpl implements OrderConverter{

    @Autowired
    private SuitService suitService;

    @Autowired
    private DeviceService deviceService;

    @Autowired
    private UserService userService;

    @Autowired
    private AreaJoinService areaJoinService;

    @Autowired
    private ChannelService channelService;

    @Autowired
    private AppService appService;

    @Override
    public OrderPrePriceVO toOrderPrePriceVO(OrderCalcPrePriceDTO dto) {
        if (dto == null) {
            return null;
        }
        // 查询套餐
        SuitVO suit = suitService.selectSuitById(dto.getSuitId());
        // 计算价格
        return OrderUtil.calcPrePrice(suit);
    }

    @Override
    public OrderCreateBO toCreateBO(OrderCreateDTO dto) {
        if (dto == null) {
            return null;
        }
        OrderCreateBO bo = new OrderCreateBO();
        bo.setDto(dto);

        // 套餐
        SuitVO suit = suitService.selectSuitById(dto.getSuitId());
        bo.setSuit(suit);

        // 设备
        DeviceVO device = deviceService.selectDeviceById(dto.getDeviceId());
        bo.setDevice(device);

        // 用户
        bo.setUser(userService.selectUserById(dto.getUserId()));

        // 加盟信息，当车辆归属用户不是当前运营区的运营商时，才有加盟信息
        if (device != null && device.getMchId() != null && !Objects.equals(device.getMchId(), device.getAreaUserId())) {
            AreaJoinVO areaJoin = areaJoinService.selectByUserArea(device.getMchId(), device.getAreaId());
            bo.setAreaJoin(areaJoin);
        }
        
        // 价格信息
        OrderPrePriceVO prePrice = OrderUtil.calcPrePrice(suit);
        bo.setPrePrice(prePrice);

        // 生成订单
        Order order = this.generateOrder(bo);
        bo.setOrder(order);

        return bo;
    }

    // 生成订单
    private Order generateOrder(OrderCreateBO bo) {
        if (bo == null) {
            return null;
        }
        Order order = new Order();
        // 基础信息
        order.setPayExpireTime(LocalDateTime.now().plusMinutes(10));

        // 用户信息
        UserVO user = bo.getUser();
        if (user != null) {
            order.setUserId(user.getUserId());
        }

        // 设备信息
        DeviceVO device = bo.getDevice();
        if (device != null) {
            order.setDeviceId(device.getId());
            order.setAreaId(device.getAreaId());
            order.setDeviceMac(device.getMac());
            order.setDeviceSn(device.getSn());
            order.setDeviceVehicleNum(device.getVehicleNum());
        }
        
        // 套餐信息
        SuitVO suit = bo.getSuit();
        if (suit != null) {
            order.setSuitId(suit.getId());
            order.setSuitType(suit.getType());
            order.setSuitName(suit.getName());
            order.setSuitFreeRideTime(suit.getFreeRideTime());
            order.setSuitRentalUnit(suit.getRentalUnit());
            order.setSuitRidingRule(suit.getRidingRule());
            order.setSuitStartRule(suit.getStartRule());
            order.setSuitIntervalRule(suit.getIntervalRule());
        }

        // 价格信息
        OrderPrePriceVO prePrice = bo.getPrePrice();
        if (prePrice != null) {
            order.setDepositFee(prePrice.getDepositPrice());
            order.setPayAmount(prePrice.getPayAmount());
        }

        // 订单状态
        if (SuitType.SHARE.getCode().equals(order.getSuitType())) {
            order.setStatus(OrderStatus.WAIT_PAY.getCode());
        } else {
            throw new RuntimeException("暂未开放租赁套餐");
        }
        
        return order;
    }

    @Override
    public OrderPayBO toPayBO(OrderVO order, Long appId, Long channelId) {
        OrderPayBO bo = new OrderPayBO();
        bo.setOrder(order);

        // 查询渠道
        ChannelVO channel = channelService.selectChannelByChannelId(channelId);
        bo.setChannel(channel);

        // 查询应用
        AppVO app = appService.selectAppById(appId);
        bo.setApp(app);

        // 查询设备
        if (order != null) {
            DeviceVO device = deviceService.selectDeviceById(order.getDeviceId());
            bo.setDevice(device);
        }

        return bo;
    }
    
}
