package com.ruoyi.bst.order.service.impl;

import java.util.Objects;

import org.springframework.stereotype.Service;

import com.ruoyi.bst.app.domain.AppVO;
import com.ruoyi.bst.channel.domain.ChannelVO;
import com.ruoyi.bst.device.domain.DeviceVO;
import com.ruoyi.bst.device.domain.enums.DeviceStatus;
import com.ruoyi.bst.order.domain.OrderVO;
import com.ruoyi.bst.order.domain.bo.OrderCreateBO;
import com.ruoyi.bst.order.domain.bo.OrderPayBO;
import com.ruoyi.bst.order.domain.dto.OrderCreateDTO;
import com.ruoyi.bst.order.domain.enums.OrderStatus;
import com.ruoyi.bst.order.domain.vo.OrderPrePriceVO;
import com.ruoyi.bst.order.service.OrderValidator;
import com.ruoyi.bst.order.utils.OrderUtil;
import com.ruoyi.bst.suit.domain.SuitVO;
import com.ruoyi.common.core.domain.vo.UserVO;
import com.ruoyi.common.utils.ServiceUtil;
import com.ruoyi.common.utils.collection.CollectionUtils;

@Service
public class OrderValidatorImpl implements OrderValidator{

    @Override
    public void validate(OrderCreateBO bo) {
        ServiceUtil.assertion(bo == null, "参数错误");

        OrderCreateDTO dto = bo.getDto();
        ServiceUtil.assertion(dto == null, "参数错误");

        // 设备
        DeviceVO device = bo.getDevice();
        ServiceUtil.assertion(device == null, "ID为%s的车辆不存在", dto.getDeviceId());
        ServiceUtil.assertion(CollectionUtils.isEmptyElement(device.getModelSuitIds()), "ID为%s的车辆无可用套餐", dto.getDeviceId());
        ServiceUtil.assertion(!DeviceStatus.canCreateOrder().contains(device.getStatus()), "ID为%s的车辆当前状态不可下单", dto.getDeviceId());

        // 套餐
        SuitVO suit = bo.getSuit();
        ServiceUtil.assertion(suit == null, "ID为%s的套餐不存在", dto.getSuitId());
        ServiceUtil.assertion(!device.getModelSuitIds().contains(suit.getId()), "ID为%s的套餐不可在ID为%s的车辆上使用", dto.getSuitId(), dto.getDeviceId());

        // 用户
        UserVO user = bo.getUser();
        ServiceUtil.assertion(user == null, "ID为%s的用户不存在", dto.getUserId());

        // 价格
        OrderPrePriceVO prePrice = bo.getPrePrice();
        ServiceUtil.assertion(prePrice == null, "价格计算失败");
        // 是否和前端传输的价格一致
        boolean priceEquals = OrderUtil.isEquals(prePrice, dto.getPrice());
        ServiceUtil.assertion(!priceEquals, "当前价格已发生变化，请刷新后重新下单");
        
    }

    @Override
    public boolean canPay(OrderVO order, Long userId) {
        return isUser(order, userId);
    }

    // 是否是下单用户
    private boolean isUser(OrderVO order, Long userId) {
        return order != null && userId != null && Objects.equals(order.getUserId(), userId);
    }

    @Override
    public void validate(OrderPayBO bo) {
        ServiceUtil.assertion(bo == null, "参数错误");

        // 订单
        OrderVO order = bo.getOrder();
        ServiceUtil.assertion(order == null, "订单不存在");
        ServiceUtil.assertion(!OrderStatus.canPay().contains(order.getStatus()), "ID为%s的订单当前状态不可支付", order.getId());
        
        // 应用
        AppVO app = bo.getApp();
        ServiceUtil.assertion(app == null, "应用不存在");


        // 渠道
        ChannelVO channel = bo.getChannel();
        ServiceUtil.assertion(channel == null, "渠道不存在");
        ServiceUtil.assertion(channel.getEnabled() == null || !channel.getEnabled(), "ID为%s的渠道暂不可用", channel.getChannelId());
        ServiceUtil.assertion(channel.getAppIds() == null || !channel.getAppIds().contains(app.getId()), "ID为%s的渠道不支持ID为%s的应用", channel.getChannelId(), app.getId());
        
        // 设备
        DeviceVO device = bo.getDevice();
        ServiceUtil.assertion(device == null, "设备不存在");

    }
    
}
