package com.ruoyi.bst.pay.service;

import java.time.LocalDateTime;
import java.util.List;

import com.ruoyi.bst.pay.domain.Pay;
import com.ruoyi.bst.pay.domain.PayQuery;
import com.ruoyi.bst.pay.domain.PayVO;
import com.ruoyi.bst.pay.domain.enums.PayBstType;
import com.ruoyi.bst.pay.domain.vo.DoPayVO;

/**
 * 支付订单Service接口
 *
 * @author ruoyi
 * @date 2025-03-26
 */
public interface PayService
{
    /**
     * 查询支付订单
     *
     * @param id 支付订单主键
     * @return 支付订单
     */
    public PayVO selectPayById(Long id);

    /**
     * 查询支付订单列表
     *
     * @param pay 支付订单
     * @return 支付订单集合
     */
    public List<PayVO> selectPayList(PayQuery pay);

    /**
     * 新增支付订单
     *
     * @param pay 支付订单
     * @return 结果
     */
    public int insertPay(Pay pay);

    /**
     * 修改支付订单
     *
     * @param pay 支付订单
     * @return 结果
     */
    public int updatePay(Pay pay);

    /**
     * 批量删除支付订单
     *
     * @param ids 需要删除的支付订单主键集合
     * @return 结果
     */
    public int deletePayByIds(Long[] ids);

    /**
     * 删除支付订单信息
     *
     * @param id 支付订单主键
     * @return 结果
     */
    public int deletePayById(Long id);

    /**
     * 创建支付订单
     */
    DoPayVO createPayBill(Pay pay);

    /**
     * 根据业务ID关闭订单
     *
     * @param bstType 业务类型
     * @param bstId   业务ID
     */
    boolean closeByBstId(String bstType, Long bstId);

    PayVO selectByNo(String no, boolean scope);

    default PayVO selectByNo(String no) {
        return selectByNo(no, false);
    }

    /**
     * 处理支付成功
     */
    void handleSuccess(String no, LocalDateTime payTime);
}
