package com.ruoyi.bst.suit.service.impl;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import com.github.pagehelper.PageHelper;
import com.ruoyi.bst.suit.domain.Suit;
import com.ruoyi.bst.suit.domain.SuitQuery;
import com.ruoyi.bst.suit.domain.SuitVO;
import com.ruoyi.bst.suit.mapper.SuitMapper;
import com.ruoyi.bst.suit.service.SuitService;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.collection.CollectionUtils;

/**
 * 套餐Service业务层处理
 *
 * @author ruoyi
 * @date 2025-03-17
 */
@Service
public class SuitServiceImpl implements SuitService
{
    @Autowired
    private SuitMapper suitMapper;

    /**
     * 查询套餐
     *
     * @param id 套餐主键
     * @return 套餐
     */
    @Override
    public SuitVO selectSuitById(Long id, boolean scope)
    {
        if (id == null) {
            return null;
        }

        SuitQuery query = new SuitQuery();
        query.setId(id);
        query.setScope(scope);
        return this.selectOne(query);
    }

    @Override
    public SuitVO selectOne(SuitQuery query) {
        PageHelper.startPage(1, 1);
        List<SuitVO> list = suitMapper.selectSuitList(query);
        return CollectionUtils.firstElement(list);
    }

    /**
     * 查询套餐列表
     *
     * @param suit 套餐
     * @return 套餐
     */
    @Override
    public List<SuitVO> selectSuitList(SuitQuery suit)
    {
        return suitMapper.selectSuitList(suit);
    }

    /**
     * 新增套餐
     *
     * @param suit 套餐
     * @return 结果
     */
    @Override
    public int insertSuit(Suit suit)
    {
        suit.setCreateTime(DateUtils.getNowDate());
        return suitMapper.insertSuit(suit);
    }

    /**
     * 修改套餐
     *
     * @param suit 套餐
     * @return 结果
     */
    @Override
    public int updateSuit(Suit suit)
    {
        return suitMapper.updateSuit(suit);
    }

    /**
     * 批量删除套餐
     *
     * @param ids 需要删除的套餐主键
     * @return 结果
     */
    @Override
    public int deleteSuitByIds(Long[] ids)
    {
        return suitMapper.deleteSuitByIds(ids);
    }

    /**
     * 删除套餐信息
     *
     * @param id 套餐主键
     * @return 结果
     */
    @Override
    public int deleteSuitById(Long id)
    {
        return suitMapper.deleteSuitById(id);
    }
}
