package com.ruoyi.system.dept.service;

import java.util.List;

import com.ruoyi.common.core.domain.TreeSelect;
import com.ruoyi.common.core.domain.entity.Dept;
import com.ruoyi.system.dept.domain.DeptQuery;
import com.ruoyi.system.dept.domain.DeptVO;
import com.ruoyi.system.dept.domain.vo.DeptNameVO;

/**
 * 部门管理 服务层
 *
 * @author ruoyi
 */
public interface DeptService
{
    /**
     * 查询部门管理数据
     *
     * @param query 部门信息
     * @return 部门信息集合
     */
    public List<DeptVO> selectDeptList(DeptQuery query);

    /**
     * 查询部门树结构信息
     *
     * @param query 部门信息
     * @return 部门树信息集合
     */
    public List<TreeSelect> selectDeptTreeList(DeptQuery query);

    /**
     * 构建前端所需要树结构
     *
     * @param depts 部门列表
     * @return 树结构列表
     */
    public List<DeptVO> buildDeptTree(List<DeptVO> depts);

    /**
     * 构建前端所需要下拉树结构
     *
     * @param depts 部门列表
     * @return 下拉树结构列表
     */
    public List<TreeSelect> buildDeptTreeSelect(List<DeptVO> depts);

    /**
     * 根据角色ID查询部门树信息
     *
     * @param roleId 角色ID
     * @return 选中部门列表
     */
    public List<Long> selectDeptListByRoleId(Long roleId);

    /**
     * 根据部门ID查询信息
     *
     * @param deptId 部门ID
     * @return 部门信息
     */
    default Dept selectDeptById(Long deptId) {
        return selectDeptById(deptId, false);
    }

    /**
     * 根据部门ID查询信息
     *
     * @param deptId 部门ID
     * @param scope
     * @return 部门信息
     */
    public Dept selectDeptById(Long deptId, boolean scope);

    /**
     * 根据ID查询所有子部门（正常状态）
     *
     * @param deptId 部门ID
     * @return 子部门数
     */
    public int selectNormalChildrenDeptById(Long deptId);

    /**
     * 是否存在部门子节点
     *
     * @param deptId 部门ID
     * @return 结果
     */
    public boolean hasChildByDeptId(Long deptId);

    /**
     * 查询部门是否存在用户
     *
     * @param deptId 部门ID
     * @return 结果 true 存在 false 不存在
     */
    public boolean checkDeptExistUser(Long deptId);

    /**
     * 校验部门名称是否唯一
     *
     * @param dept 部门信息
     * @return 结果
     */
    public boolean checkDeptNameUnique(Dept dept);

    /**
     * 校验部门是否有数据权限
     *
     * @param deptId 部门id
     */
    public void checkDeptDataScope(Long deptId);

    /**
     * 新增保存部门信息
     *
     * @param dept 部门信息
     * @return 结果
     */
    public int insertDept(Dept dept);

    /**
     * 修改保存部门信息
     *
     * @param dept 部门信息
     * @return 结果
     */
    public int updateDept(Dept dept);

    /**
     * 删除部门管理信息
     *
     * @param deptId 部门ID
     * @return 结果
     */
    public int deleteDeptById(Long deptId);

    /**
     * 根据名称列表，查询部门
     */
    List<DeptVO> selectDeptListByNames(List<String> names);

    /**
     * 查询所有部门名称列表
     */
    List<DeptNameVO> selectAllDeptNameList();
}
