package com.ruoyi.web.bst;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.bst.bonus.domain.Bonus;
import com.ruoyi.bst.bonus.domain.BonusVO;
import com.ruoyi.bst.bonus.domain.BonusQuery;
import com.ruoyi.bst.bonus.service.BonusService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 分成明细Controller
 *
 * @author ruoyi
 * @date 2025-03-26
 */
@RestController
@RequestMapping("/bst/bonus")
public class BonusController extends BaseController
{
    @Autowired
    private BonusService bonusService;

    /**
     * 查询分成明细列表
     */
    @PreAuthorize("@ss.hasPermi('bst:bonus:list')")
    @GetMapping("/list")
    public TableDataInfo list(BonusQuery query)
    {
        startPage();
        startOrderBy();
        List<BonusVO> list = bonusService.selectBonusList(query);
        return getDataTable(list);
    }

    /**
     * 导出分成明细列表
     */
    @PreAuthorize("@ss.hasPermi('bst:bonus:export')")
    @Log(title = "分成明细", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BonusQuery query)
    {
        List<BonusVO> list = bonusService.selectBonusList(query);
        ExcelUtil<BonusVO> util = new ExcelUtil<BonusVO>(BonusVO.class);
        util.exportExcel(response, list, "分成明细数据");
    }

    /**
     * 获取分成明细详细信息
     */
    @PreAuthorize("@ss.hasPermi('bst:bonus:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(bonusService.selectBonusById(id));
    }

    /**
     * 新增分成明细
     */
    @PreAuthorize("@ss.hasPermi('bst:bonus:add')")
    @Log(title = "分成明细", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Bonus bonus)
    {
        return toAjax(bonusService.insertBonus(bonus));
    }

    /**
     * 修改分成明细
     */
    @PreAuthorize("@ss.hasPermi('bst:bonus:edit')")
    @Log(title = "分成明细", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Bonus bonus)
    {
        return toAjax(bonusService.updateBonus(bonus));
    }

    /**
     * 删除分成明细
     */
    @PreAuthorize("@ss.hasPermi('bst:bonus:remove')")
    @Log(title = "分成明细", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(bonusService.deleteBonusByIds(ids));
    }
}
